@@ -103,7 +103,7 @@ class Drone:
 
     def is_open(self):
         if self._serialport != None:
-            return self._serialport.is_open()
+            return self._serialport.is_open
         else:
             return False
 
